require "/scripts/messageutil.lua"

local oldInit = init;
local oldUpdate = update;

function init()
	oldInit()
	message.setHandler("badgetracker_changeSize", localHandler(changeSize))
	message.setHandler("badgetracker_unequip", localHandler(unequip))
end

function update(dt)
	oldUpdate(dt)
	if isWearingBadge then
		if not ((player.equippedItem("legsCosmetic") and player.equippedItem("legsCosmetic").parameters.isBadgeItem) and (player.equippedItem("chestCosmetic") and player.equippedItem("chestCosmetic").parameters.isBadgeItem)) then
			unequip()
			changeSize(itemType)
		end
	end
end

function changeSize(bodyType)
    if (not legsSet) or (not chestSet) then
        checkClothes()
    end

	itemType = bodyType
	isWearingBadge = true
	local legsItem = {name=itemType..player.species():lower().."legs", count=1}
	local chestItem = {name=itemType..player.species():lower().."chest", count=1}

	local legClothing = false
	if legsSet and legsSet[bodyType] then
		legsItem.name = legsSet[bodyType]
		legClothing = true
	end

	local chestClothing = false
	if chestSet and chestSet[bodyType] then
		chestItem.name = chestSet[bodyType]
		chestClothing = true
	end

	if not (pcall(root.itemType, legsItem.name) or pcall(root.itemType, chestItem.name)) then
		sb.logError("BadgeTracker: %s","No species item found")
		sb.logError("BadgeTracker: %s, %s",legsItem.name, chestItem.name)
	end
	if player then
		local portrait = world.entityPortrait(player.id(), "full")
		local bodyDirectives = ""
		for key, value in pairs(portrait) do
			if string.find(portrait[key].image, "body.png") then
				local body_image =  portrait[key].image
				local directive_location = string.find(body_image, "replace")
				bodyDirectives = string.sub(body_image,directive_location)
				break
			end
		end
		if legClothing then
			legsItem.parameters = {colorIndex = legsColor, price = 0, isBadgeItem = true}
		else
			legsItem.parameters = {directives = "?"..bodyDirectives, price = 0, isBadgeItem = true}
		end
		if chestClothing then
			chestItem.parameters = {colorIndex = chestColor, price = 0, isBadgeItem = true}
		else
			chestItem.parameters = {directives = "?"..bodyDirectives, price = 0, isBadgeItem = true}
		end
		if pcall(root.itemType, legsItem.name) then
			if player.equippedItem("legsCosmetic") and not player.equippedItem("legsCosmetic").parameters.isBadgeItem and not player.equippedItem("legsCosmetic").name:find(itemType) then
				player.giveItem(player.equippedItem("legsCosmetic"))
			end
			if not (player.equippedItem("legsCosmetic") and player.equippedItem("legsCosmetic").name:find(itemType)) then
				player.setEquippedItem("legsCosmetic", legsItem)
			end
		end
		if pcall(root.itemType, chestItem.name) then
			if player.equippedItem("chestCosmetic") and not player.equippedItem("chestCosmetic").parameters.isBadgeItem and not player.equippedItem("chestCosmetic").name:find(itemType) then
				player.giveItem(player.equippedItem("chestCosmetic"))
			end
			if not (player.equippedItem("chestCosmetic") and player.equippedItem("chestCosmetic").name:find(itemType)) then
				player.setEquippedItem("chestCosmetic", chestItem)
			end
		end
	end
end

function checkClothes()
	legsSet = nil
	chestSet = nil
    
    local fattyClothingSets = root.assetJson("/items/armors/fattyclothingsets.config")
    local fattyLegsSets = fattyClothingSets.fattyLegsSets
    local fattyChestSets = fattyClothingSets.fattyChestSets

	local legsCosmetic = player.equippedItem("legsCosmetic")
	local legsFound = false
	if legsCosmetic then
		local legsName = legsCosmetic.name
		legsColor = legsCosmetic.parameters.colorIndex

		for _, set in ipairs(fattyLegsSets) do
			for key, value in pairs(set) do
				if legsName == value then
					legsFound = true
					legsSet = set
					break
				end
			end
			if legsFound then
				break
			end
		end
	end

	local chestCosmetic = player.equippedItem("chestCosmetic")
	local chestFound = false
	if chestCosmetic then
		local chestName = chestCosmetic.name
		chestColor = chestCosmetic.parameters.colorIndex

		for _, set in ipairs(fattyChestSets) do
			for key, value in pairs(set) do
				if chestName == value then
					chestFound = true
					chestSet = set
					break
				end
			end
			if chestFound then
				break
			end
		end
	end
end

function unequip()
	player.consumeItemWithParameter("isBadgeItem", true, 1000)
	isWearingBadge = false
end