require "/scripts/messageutil.lua"

local oldInit = init;
local oldUpdate = update;

function init()
	oldInit()
	defaultArmor = status.statusProperty("defaultArmor") or {
		legs = npc.getItemSlot("legs"),
		chest = npc.getItemSlot("chest")
	}
    
    if (not defaultArmor.legsSet) or (not defaultArmor.chestSet) then
        local fattyClothingSets = root.assetJson("/items/armors/fattyclothingsets.config")
        local fattyLegsSets = fattyClothingSets.fattyLegsSets
        local fattyChestSets = fattyClothingSets.fattyChestSets
        
        local legsName = defaultArmor.legs.name
        local chestName = defaultArmor.chest.name
        
		for _, set in ipairs(fattyLegsSets) do
			for key, value in pairs(set) do
				if legsName == value then
					legsFound = true
					defaultArmor.legsSet = set
					break
				end
			end
			if legsFound then
				break
			end
		end
		for _, set in ipairs(fattyChestSets) do
			for key, value in pairs(set) do
				if chestName == value then
					chestFound = true
					defaultArmor.chestSet = set
					break
				end
			end
			if chestFound then
				break
			end
		end
    end
    
	status.setStatusProperty("defaultArmor", defaultArmor)
	
    message.setHandler("badgetracker_changeSize", localHandler(changeSize))
    message.setHandler("badgetracker_unequip", localHandler(unequip))
end

function changeSize(bodyType)
	itemType = bodyType
	local legsItem = {name=itemType..npc.species():lower().."legs", count=1}
	local chestItem = {name=itemType..npc.species():lower().."chest", count=1}
    
    if defaultArmor.legsSet and defaultArmor.legsSet[bodyType] then
        legsItem.name = defaultArmor.legsSet[bodyType]
    end
    if defaultArmor.chestSet and defaultArmor.chestSet[bodyType] then
        chestItem.name = defaultArmor.chestSet[bodyType]
    end

	if not (pcall(root.itemType, legsItem.name) or pcall(root.itemType, chestItem.name)) then
		sb.logError("%s","No species item found")
	end
	local portrait = world.entityPortrait(entity.id(), "full")
	local bodyDirectives = ""
	for key, value in pairs(portrait) do
		if string.find(portrait[key].image, "body.png") then
			local body_image =  portrait[key].image
			local directive_location = string.find(body_image, "replace")
			bodyDirectives = string.sub(body_image,directive_location)
			break
		end
	end
	legsItem.parameters = sb.jsonMerge(defaultArmor.legs.parameters, {price = 0, isBadgeItem = true})
	chestItem.parameters = sb.jsonMerge(defaultArmor.chest.parameters, {price = 0, isBadgeItem = true})
    
    if (not defaultArmor.legsSet) or (not defaultArmor.legsSet[bodyType]) then
        legsItem.parameters.directives = "?"..bodyDirectives
    end
    if (not defaultArmor.chestSet) or (not defaultArmor.chestSet[bodyType]) then
        chestItem.parameters.directives = "?"..bodyDirectives
    end
    
	if pcall(root.itemType, legsItem.name) then
		if not (npc.getItemSlot("legs") and npc.getItemSlot("legs").name:find(itemType)) then
			npc.setItemSlot("legs", legsItem)
		end
	end
	if pcall(root.itemType, chestItem.name) then
		if not (npc.getItemSlot("chest") and npc.getItemSlot("chest").name:find(itemType)) then
			npc.setItemSlot("chest", chestItem)
		end
	end
end

function unequip()
	npc.setItemSlot("chest", defaultArmor.chest)
	npc.setItemSlot("legs", defaultArmor.legs)
end